#include <SPI.h>

byte chipSelectPin = 42; // EEPROM의 SS
byte chipSelectArduinoUno = 53; // 아두이노 우노의 SS

#define READ 0x03 // 읽기 명령
#define WRITE 0x02 // 쓰기 명령
#define WREN 0x06 // 쓰기 허용 명령

void setup() {
  pinMode(chipSelectPin, OUTPUT);
  pinMode(chipSelectArduinoUno, OUTPUT);
  digitalWrite(chipSelectArduinoUno, HIGH);
  SPI.begin();
  Serial.begin(9600);
}

void loop() {
  int address = 10;
  int data = 1000;
  
  write_eeprom_int(address, data);
  Serial.print("Write to address ");
  Serial.print(address);
  Serial.print(", value is ");
  Serial.println(data);
  data = read_eeprom_int(address);
  Serial.print("Read from address ");
  Serial.print(address);
  Serial.print(", value is ");
  Serial.println(data);
  while (true);
}

int read_eeprom_int(int address) {
  byte data1 = read_eeprom(address);
  byte data2 = read_eeprom(address + 1);
  return ( (data1 << 8) + data2);
}

void write_eeprom_int(int address, int data) {
  write_eeprom(address, data >> 8);
  delay(5);
  write_eeprom(address + 1, data & 0xFF);
  delay(5);
}

byte read_eeprom(int address) {
  digitalWrite(chipSelectPin, LOW);
  SPI.transfer(READ); // READ 명령
  SPI.transfer( (byte)(address >> 8) ); // 상위 8비트 주소
  SPI.transfer( (byte) address ); // 하위 8비트 주소
  // 데이터를 읽기 위해 의미 없는 바이트 값을 전송
  int data = SPI.transfer(0x00);
  digitalWrite(chipSelectPin, HIGH);
  return data;
}

void write_eeprom(int address, byte data) {
  // WREN 명령 전송
  digitalWrite(chipSelectPin, LOW);
  SPI.transfer(WREN);
  digitalWrite(chipSelectPin, HIGH);
  // 데이터 기록
  digitalWrite(chipSelectPin, LOW);
  SPI.transfer(WRITE); // WRITE 명령
  SPI.transfer( (byte)(address >> 8) ); // 상위 8비트 주소
  SPI.transfer( (byte) address ); // 하위 8비트 주소
  SPI.transfer(data); // 데이터
  digitalWrite(chipSelectPin, HIGH);
}
